#
# spec file for package python-websockify
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-websockify
Version:        0.8.0
Release:        9.3.1
Summary:        WebSocket to TCP proxy/bridge
License:        LGPL-3.0-only AND MPL-2.0 AND BSD-2-Clause AND BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/kanaka/websockify
Source:         https://files.pythonhosted.org/packages/source/w/websockify/websockify-%{version}.tar.gz
# PATCH-FEATURE-UPSTREAM u_Add-support-for-inetd.patch fate#323880 msrb@suse.com -- https://github.com/novnc/websockify/pull/293
Patch1:         u_Add-support-for-inetd.patch
# PATCH-FEATURE-UPSTREAM u_Fix-inetd-mode-on-python-2.patch fate#323880 msrb@suse.com -- https://github.com/novnc/websockify/pull/293
Patch2:         u_Fix-inetd-mode-on-python-2.patch
# PATCH-FEATURE-ALMOST-UPSTREAM u_added_jwt_tokens_capability.patch fate#325762 cbosdonnat@suse.com -- https://github.com/novnc/websockify/pull/372
Patch3:         u_added_jwt_tokens_capability.patch
# PATCH-FIX-OPENSUSE PyJWT-token-plugin.patch fate#325762 cbosdonnat@suse.com -- use PyJWT if jwcrypto is missing
Patch4:         PyJWT-token-plugin.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
Requires:       python-setuptools
Requires:       python-websockify-common = %{version}
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%if 0%{?suse_version}
Requires:       python-numpy
%endif
# SLES 12 and up to 15SP1 doesn't have python-jwcrypto package and will fallback to
# the PyJWT implementation. However opensuse has jwcrypto since 42.3: use this one
# since it also provides support for JWE (encrypted JWT).
%if 0%{?sle_version}
Recommends:     python-PyJWT
Recommends:     python-cryptography
%else
Recommends:     python-jwcrypto
%endif
%python_subpackages

%description
websockify was formerly named wsproxy and was part of the
noVNC project.

At the most basic level, websockify just translates WebSockets traffic
to normal socket traffic. Websockify accepts the WebSockets handshake,
parses it, and then begins forwarding traffic between the client and
the target in both directions.

%package -n python-websockify-common
Summary:        Common data files for the Websockify TCP proxy/bridge
Group:          Development/Languages/Python
Provides:       %{python_module websockify-common = %{version}}

%description -n python-websockify-common
websockify was formerly named wsproxy and was part of the
noVNC project.

At the most basic level, websockify just translates WebSockets traffic
to normal socket traffic. Websockify accepts the WebSockets handshake,
parses it, and then begins forwarding traffic between the client and
the target in both directions.

This package contains common files.

%prep
%setup -q -n websockify-%{version}
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
# remove unwanted shebang
sed -i '1 { /^#!/ d }' websockify/websocket*.py
# drop unneeded executable bit
chmod -x include/web-socket-js/web_socket.js

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/websockify

%post
%python_install_alternative websockify

%postun
%python_uninstall_alternative websockify

%files %{python_files}
%license LICENSE.txt
%doc CHANGES.txt README.md
%python_alternative %{_bindir}/websockify
%{python_sitelib}/*

%files -n python-websockify-common
%license LICENSE.txt
%{_datadir}/websockify

%changelog
* Mon Dec 21 2020 bwiedemann@suse.com
- Require python-numpy at runtime (boo#1163513)
* Tue Feb 12 2019 cbosdonnat@suse.com
- Add JWT token plugin feature.
  Added patches:
    u_added_jwt_tokens_capability.patch
    PyJWT-token-plugin.patch: fate#325762
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Mon Oct  2 2017 jengelh@inai.de
- Improve summaries.
* Mon Sep 25 2017 msrb@suse.com
- add u_Add-support-for-inetd.patch: fate#323880
- add u_Fix-inetd-mode-on-python-2.patch: fate#323880
* Fri Aug 25 2017 tbechtold@suse.com
- use https for Source
* Fri Aug 25 2017 tbechtold@suse.com
- convert to singlespec
- split data files into -common package
* Sat Jul 22 2017 dmueller@suse.com
- drop dependency on pyOpenSSL, seems unused (bsc#1049987)
* Mon May  2 2016 dmueller@suse.com
- update to 0.8.0:
  * Make websockify properly terminate children on SIGTERM (#226)
  * Remove logging in signal handlers (this can cause Python to hang under certain conditions) (#219)
  * Make it easier to log to a file (#205)
  * Add support for IPv6 addresses in tokens in the TokenFile token plugins (#197)
  * Improve auth plugin framework to enable better support for HTTP auth (#194, #201)
  * Fix bug in JSONTokenAPI token plugin (#192)
  * Fix a missing variable in the exception handler (#178)
  * Python 3 support fixes (#140, #155, #159)
  * Generic token-parsing plugins support (#162)
  * Generic authentication plugins support (#172)
  * Fixed frame corruption on big-endian systems (#161)
  * Support heartbeats (via PING) and automatic responses to PONG (#169)
  * Automatically reject unmasked client frames by default (strict mode) (#174)
  * Automatically restart interrupted select calls (#175)
  * Make 'run' respect environment settings (including virtualenv) (#176)
* Mon Oct  5 2015 hguo@suse.com
- Add missing dependency on python-setuptools
* Sat Jul 25 2015 seife+obs@b1-systems.com
- fix non-SUSE build by conditionalizing "Recommends:" tag
* Thu May 14 2015 benoit.monin@gmx.fr
- update to version 0.6.1:
  * PATCH RELEASE: Fixes a bug causing file_only to not be passed
    properly
- switch archive to zip (tar.gz not available on pypi)
- add unzip as BuildRequires
- remove unwanted shebang in python files
- drop unneeded executable bit of web_socket.js
* Tue Sep 16 2014 tbechtold@suse.com
- update to version 0.6.0:
  * **NOTE** : 0.6.0 will break existing code that sub-classes WebsocketProxy
  * Refactor to use standard SocketServer RequestHandler design
  * Fix zombie process bug on certain systems when using multiprocessing
  * Add better unit tests
  * Log information via python `logging` module
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Wed Jul  3 2013 dmueller@suse.com
- update to 0.5.1:
  * use upstream einaros/ws (>=0.4.27) with websockify.js
  * file_only and no_parent security options for WSRequestHandler
  * Update build of web-socket-js (c0855c6cae)
  * add include/web-socket-js-project submodule to gimite/web-socket-js
    for DSFG compliance.
  * drop Hixie protocol support
* Mon Apr 29 2013 dmueller@suse.com
- update to 0.4.1:
  * add include/ directory and remove some dev files from source
    distribution.
  * use Buffer base64 support in Node.js implementation
* Fri Jan 18 2013 cfarrell@suse.com
- license update: LGPL-3.0 and MPL-2.0 and BSD-2-Clause and BSD-3-Clause
  See LICENSE.txt
* Thu Jan 17 2013 saschpe@suse.de
- Initial version
